@ECHO OFF

pushd %~dp0

REM Command file for Sphinx documentation

if "%SPHINXBUILD%" == "" (
  set SPHINXBUILD=sphinx-build

System Message: WARNING/2 (`E:/Models/FINE/FINE/docs/make.bat`, line 9)

Definition list ends without a blank line; unexpected unindent.

) set SOURCEDIR=source set BUILDDIR=build set SPHINXPROJ=FINE

if "%1" == "" goto help

%SPHINXBUILD% >NUL 2>NUL if errorlevel 9009 (

System Message: ERROR/3 (`E:/Models/FINE/FINE/docs/make.bat`, line 18)

Unexpected indentation.

> echo. echo.The 'sphinx-build' command was not found. Make sure you have Sphinx echo.installed, then set the SPHINXBUILD environment variable to point echo.to the full path of the 'sphinx-build' executable. Alternatively you echo.may add the Sphinx directory to PATH. echo. echo.If you don't have Sphinx installed, grab it from echo.http://sphinx-doc.org/ exit /b 1

System Message: WARNING/2 (`E:/Models/FINE/FINE/docs/make.bat`, line 27)

Block quote ends without a blank line; unexpected unindent.

)

%SPHINXBUILD% -M %1 %SOURCEDIR% %BUILDDIR% %SPHINXOPTS% goto end

:help %SPHINXBUILD% -M help %SOURCEDIR% %BUILDDIR% %SPHINXOPTS%

:end popd